@@ -1,9 +1,12 @@
 import json
 import re
-from typing import Any, Callable, Dict, List, Pattern, Sequence, Union
+from typing import TYPE_CHECKING, Callable, Dict, List, Pattern, Sequence, Union
 
 from .loaders import BaseLoader, DictLoader
 
+if TYPE_CHECKING:  # pragma: no cover
+    from pydantic.error_wrappers import ErrorDict
+
 __all__ = ("PydanticI18n",)
 
 
@@ -52,12 +55,12 @@ class PydanticI18n:
 
     def translate(
         self,
-        errors: List[Dict[str, Any]],
+        errors: List["ErrorDict"],
         locale: str,
-    ) -> List[Dict[str, Any]]:
+    ) -> List["ErrorDict"]:
         return [
             {
-                **error,
+                **error,  # type: ignore
                 "msg": self._translate(error["msg"], locale),
             }
             for error in errors
